@@ -10,6 +10,12 @@ pub(crate) enum CompileErrorKind<'src> {
     alias: &'src str,
     recipe_line: usize,
   },
+  AttributeArgumentCountMismatch {
+    attribute: &'src str,
+    found: usize,
+    min: usize,
+    max: usize,
+  },
   BacktickShebang,
   CircularRecipeDependency {
     recipe: &'src str,
@@ -82,12 +88,12 @@ pub(crate) enum CompileErrorKind<'src> {
   RequiredParameterFollowsDefaultParameter {
     parameter: &'src str,
   },
+  ShellExpansion {
+    err: shellexpand::LookupError<env::VarError>,
+  },
   UndefinedVariable {
     variable: &'src str,
   },
-  UnexpectedAttributeArgument {
-    attribute: Attribute<'src>,
-  },
   UnexpectedCharacter {
     expected: char,
   },
