@@ -2,6 +2,7 @@ use {
   super::*,
   clap::{
     builder::{styling::AnsiColor, FalseyValueParser, PossibleValuesParser, Styles},
+    parser::ValuesRef,
     value_parser, Arg, ArgAction, ArgGroup, ArgMatches, Command,
   },
 };
@@ -31,6 +32,7 @@ pub(crate) struct Config {
   pub(crate) invocation_directory: PathBuf,
   pub(crate) list_heading: String,
   pub(crate) list_prefix: String,
+  pub(crate) list_submodules: bool,
   pub(crate) load_dotenv: bool,
   pub(crate) no_aliases: bool,
   pub(crate) no_dependencies: bool,
@@ -39,6 +41,8 @@ pub(crate) struct Config {
   pub(crate) shell_args: Option<Vec<String>>,
   pub(crate) shell_command: bool,
   pub(crate) subcommand: Subcommand,
+  pub(crate) timestamp: bool,
+  pub(crate) timestamp_format: String,
   pub(crate) unsorted: bool,
   pub(crate) unstable: bool,
   pub(crate) verbosity: Verbosity,
@@ -79,9 +83,8 @@ mod cmd {
     VARIABLES,
   ];
 
-  pub(crate) const ARGLESS: &[&str] = &[
-    CHANGELOG, DUMP, EDIT, FORMAT, INIT, LIST, MAN, SUMMARY, VARIABLES,
-  ];
+  pub(crate) const ARGLESS: &[&str] =
+    &[CHANGELOG, DUMP, EDIT, FORMAT, INIT, MAN, SUMMARY, VARIABLES];
 }
 
 mod arg {
@@ -95,11 +98,12 @@ mod arg {
   pub(crate) const DOTENV_PATH: &str = "DOTENV-PATH";
   pub(crate) const DRY_RUN: &str = "DRY-RUN";
   pub(crate) const DUMP_FORMAT: &str = "DUMP-FORMAT";
-  pub(crate) const GLOBAL_JUSTFILE: &str = "GLOBAL_JUSTFILE";
+  pub(crate) const GLOBAL_JUSTFILE: &str = "GLOBAL-JUSTFILE";
   pub(crate) const HIGHLIGHT: &str = "HIGHLIGHT";
   pub(crate) const JUSTFILE: &str = "JUSTFILE";
   pub(crate) const LIST_HEADING: &str = "LIST-HEADING";
   pub(crate) const LIST_PREFIX: &str = "LIST-PREFIX";
+  pub(crate) const LIST_SUBMODULES: &str = "LIST-SUBMODULES";
   pub(crate) const NO_ALIASES: &str = "NO-ALIASES";
   pub(crate) const NO_DEPS: &str = "NO-DEPS";
   pub(crate) const NO_DOTENV: &str = "NO-DOTENV";
@@ -109,6 +113,8 @@ mod arg {
   pub(crate) const SHELL: &str = "SHELL";
   pub(crate) const SHELL_ARG: &str = "SHELL-ARG";
   pub(crate) const SHELL_COMMAND: &str = "SHELL-COMMAND";
+  pub(crate) const TIMESTAMP: &str = "TIMESTAMP";
+  pub(crate) const TIMESTAMP_FORMAT: &str = "TIMESTAMP-FORMAT";
   pub(crate) const UNSORTED: &str = "UNSORTED";
   pub(crate) const UNSTABLE: &str = "UNSTABLE";
   pub(crate) const VERBOSE: &str = "VERBOSE";
@@ -232,6 +238,13 @@ impl Config {
           .value_name("TEXT")
           .action(ArgAction::Set),
       )
+      .arg(
+        Arg::new(arg::LIST_SUBMODULES)
+          .long("list-submodules")
+          .help("List recipes in submodules")
+          .action(ArgAction::SetTrue)
+          .env("JUST_LIST_SUBMODULES"),
+      )
       .arg(
         Arg::new(arg::NO_ALIASES)
           .long("no-aliases")
@@ -415,8 +428,11 @@ impl Config {
         Arg::new(cmd::LIST)
           .short('l')
           .long("list")
-          .action(ArgAction::SetTrue)
-          .help("List available recipes and their arguments"),
+          .num_args(0..)
+          .value_name("PATH")
+          .action(ArgAction::Set)
+          .conflicts_with(arg::ARGUMENTS)
+          .help("List available recipes"),
       )
       .arg(
         Arg::new(cmd::GROUPS)
@@ -434,10 +450,11 @@ impl Config {
         Arg::new(cmd::SHOW)
           .short('s')
           .long("show")
+          .num_args(1..)
           .action(ArgAction::Set)
-          .value_name("RECIPE")
+          .value_name("PATH")
           .conflicts_with(arg::ARGUMENTS)
-          .help("Show information about <RECIPE>"),
+          .help("Show recipe at <PATH>"),
       )
       .arg(
         Arg::new(cmd::SUMMARY)
@@ -482,6 +499,21 @@ impl Config {
       .conflicts_with(arg::WORKING_DIRECTORY)
       .help("Use global justfile")
     )
+    .arg(
+      Arg::new(arg::TIMESTAMP)
+      .action(ArgAction::SetTrue)
+      .long("timestamp")
+      .env("JUST_TIMESTAMP")
+      .help("Print recipe command timestamps")
+    )
+    .arg(
+      Arg::new(arg::TIMESTAMP_FORMAT)
+      .action(ArgAction::Set)
+      .long("timestamp-format")
+      .env("JUST_TIMESTAMP_FORMAT")
+      .default_value("%H:%M:%S")
+      .help("Timestamp format string")
+    )
   }
 
   fn color_from_matches(matches: &ArgMatches) -> ConfigResult<Color> {
@@ -537,6 +569,18 @@ impl Config {
     }
   }
 
+  fn parse_module_path(path: ValuesRef<String>) -> ConfigResult<ModulePath> {
+    path
+      .clone()
+      .map(|s| (*s).as_str())
+      .collect::<Vec<&str>>()
+      .as_slice()
+      .try_into()
+      .map_err(|()| ConfigError::ModulePath {
+        path: path.cloned().collect(),
+      })
+  }
+
   fn search_config(matches: &ArgMatches, positional: &Positional) -> ConfigResult<SearchConfig> {
     if matches.get_flag(arg::GLOBAL_JUSTFILE) {
       return Ok(SearchConfig::GlobalJustfile);
@@ -654,14 +698,18 @@ impl Config {
       Subcommand::Format
     } else if matches.get_flag(cmd::INIT) {
       Subcommand::Init
-    } else if matches.get_flag(cmd::LIST) {
-      Subcommand::List
+    } else if let Some(path) = matches.get_many::<String>(cmd::LIST) {
+      Subcommand::List {
+        path: Self::parse_module_path(path)?,
+      }
     } else if matches.get_flag(cmd::GROUPS) {
       Subcommand::Groups
     } else if matches.get_flag(cmd::MAN) {
       Subcommand::Man
-    } else if let Some(name) = matches.get_one::<String>(cmd::SHOW).map(Into::into) {
-      Subcommand::Show { name }
+    } else if let Some(path) = matches.get_many::<String>(cmd::SHOW) {
+      Subcommand::Show {
+        path: Self::parse_module_path(path)?,
+      }
     } else if matches.get_flag(cmd::EVALUATE) {
       if positional.arguments.len() > 1 {
         return Err(ConfigError::SubcommandArguments {
@@ -715,6 +763,7 @@ impl Config {
       list_prefix: matches
         .get_one::<String>(arg::LIST_PREFIX)
         .map_or_else(|| "    ".into(), Into::into),
+      list_submodules: matches.get_flag(arg::LIST_SUBMODULES),
       load_dotenv: !matches.get_flag(arg::NO_DOTENV),
       no_aliases: matches.get_flag(arg::NO_ALIASES),
       no_dependencies: matches.get_flag(arg::NO_DEPS),
@@ -723,6 +772,11 @@ impl Config {
       shell_args,
       shell_command: matches.get_flag(arg::SHELL_COMMAND),
       subcommand,
+      timestamp: matches.get_flag(arg::TIMESTAMP),
+      timestamp_format: matches
+        .get_one::<String>(arg::TIMESTAMP_FORMAT)
+        .unwrap()
+        .into(),
       unsorted: matches.get_flag(arg::UNSORTED),
       unstable,
       verbosity,
@@ -1263,30 +1317,42 @@ mod tests {
   test! {
     name: subcommand_list_long,
     args: ["--list"],
-    subcommand: Subcommand::List,
+    subcommand: Subcommand::List{ path: ModulePath { path: Vec::new(), spaced: false } },
   }
 
   test! {
     name: subcommand_list_short,
     args: ["-l"],
-    subcommand: Subcommand::List,
+    subcommand: Subcommand::List{ path: ModulePath { path: Vec::new(), spaced: false } },
+  }
+
+  test! {
+    name: subcommand_list_arguments,
+    args: ["--list", "bar"],
+    subcommand: Subcommand::List{ path: ModulePath { path: vec!["bar".into()], spaced: false } },
   }
 
   test! {
     name: subcommand_show_long,
     args: ["--show", "build"],
-    subcommand: Subcommand::Show { name: String::from("build") },
+    subcommand: Subcommand::Show { path: ModulePath { path: vec!["build".into()], spaced: false } },
   }
 
   test! {
     name: subcommand_show_short,
     args: ["-s", "build"],
-    subcommand: Subcommand::Show { name: String::from("build") },
+    subcommand: Subcommand::Show { path: ModulePath { path: vec!["build".into()], spaced: false } },
   }
 
-  error! {
-    name: subcommand_show_no_arg,
-    args: ["--show"],
+  test! {
+    name: subcommand_show_multiple_args,
+    args: ["--show", "foo", "bar"],
+    subcommand: Subcommand::Show {
+      path: ModulePath {
+        path: vec!["foo".into(), "bar".into()],
+        spaced: true,
+      },
+    },
   }
 
   test! {
@@ -1501,16 +1567,6 @@ mod tests {
     },
   }
 
-  error! {
-    name: list_arguments,
-    args: ["--list", "bar"],
-    error: ConfigError::SubcommandArguments { subcommand, arguments },
-    check: {
-      assert_eq!(subcommand, cmd::LIST);
-      assert_eq!(arguments, &["bar"]);
-    },
-  }
-
   error! {
     name: dump_arguments,
     args: ["--dump", "bar"],
@@ -1571,20 +1627,6 @@ mod tests {
     },
   }
 
-  error_matches! {
-    name: show_arguments,
-    args: ["--show", "foo", "bar"],
-    error: error,
-    check: {
-      assert_eq!(error.kind(), clap::error::ErrorKind::ArgumentConflict);
-      assert_eq!(error.context().collect::<Vec<_>>(), vec![
-        (ContextKind::InvalidArg, &ContextValue::String("--show <RECIPE>".into())),
-        (ContextKind::PriorArg, &ContextValue::String("[ARGUMENTS]...".into())),
-        (ContextKind::Usage, &ContextValue::StyledStr("\u{1b}[33mUsage:\u{1b}[0m \u{1b}[32mjust\u{1b}[0m \u{1b}[32m--show\u{1b}[0m\u{1b}[32m \u{1b}[0m\u{1b}[32m<RECIPE>\u{1b}[0m \u{1b}[32m[ARGUMENTS]...\u{1b}[0m".into())),
-      ]);
-    },
-  }
-
   error! {
     name: summary_arguments,
     args: ["--summary", "bar"],
