@@ -20,7 +20,7 @@ pub(crate) enum Error<'src> {
     token: Token<'src>,
     output_error: OutputError,
   },
-  CacheDirIo {
+  RuntimeDirIo {
     io_error: io::Error,
     path: PathBuf,
   },
@@ -79,6 +79,7 @@ pub(crate) enum Error<'src> {
   Dotenv {
     dotenv_error: dotenvy::Error,
   },
+  DotenvRequired,
   DumpJson {
     serde_json_error: serde_json::Error,
   },
@@ -160,6 +161,9 @@ pub(crate) enum Error<'src> {
     recipe: &'src str,
     line_number: Option<usize>,
   },
+  UnknownSubmodule {
+    path: ModulePath,
+  },
   UnknownOverrides {
     overrides: Vec<String>,
   },
@@ -283,9 +287,6 @@ impl<'src> ColorDisplay for Error<'src> {
           }?,
         OutputError::Utf8(utf8_error) => write!(f, "Backtick succeeded but stdout was not utf8: {utf8_error}")?,
       }
-      CacheDirIo { io_error, path } => {
-        write!(f, "I/O error in cache dir `{}`: {io_error}", path.display())?;
-      }
       ChooserInvoke { shell_binary, shell_arguments, chooser, io_error} => {
         let chooser = chooser.to_string_lossy();
         write!(f, "Chooser `{shell_binary} {shell_arguments} {chooser}` invocation failed: {io_error}")?;
@@ -344,6 +345,9 @@ impl<'src> ColorDisplay for Error<'src> {
       Dotenv { dotenv_error } => {
         write!(f, "Failed to load environment file: {dotenv_error}")?;
       }
+      DotenvRequired => {
+        write!(f, "Dotenv file not found")?;
+      }
       DumpJson { serde_json_error } => {
         write!(f, "Failed to dump JSON to stdout: {serde_json_error}")?;
       }
@@ -400,6 +404,9 @@ impl<'src> ColorDisplay for Error<'src> {
         write!(f, "Recipe `{recipe}` was not confirmed")?;
       }
       RegexCompile { source } => write!(f, "{source}")?,
+      RuntimeDirIo { io_error, path } => {
+        write!(f, "I/O error in runtime dir `{}`: {io_error}", path.display())?;
+      }
       Search { search_error } => Display::fmt(search_error, f)?,
       Shebang { recipe, command, argument, io_error} => {
         if let Some(argument) = argument {
@@ -432,6 +439,9 @@ impl<'src> ColorDisplay for Error<'src> {
           write!(f, "Recipe `{recipe}` failed for an unknown reason")?;
         }
       }
+      UnknownSubmodule { path } => {
+        write!(f, "Justfile does not contain submodule `{path}`")?;
+      }
       UnknownOverrides { overrides } => {
         let count = Count("Variable", overrides.len());
         let overrides = List::and_ticked(overrides);
