@@ -18,15 +18,16 @@ use {super::*, TokenKind::*};
 /// All methods starting with `parse_*` parse and return a language construct.
 ///
 /// The parser tracks an expected set of tokens as it parses. This set contains
-/// all tokens which would have been accepted at the current point in the parse.
-/// Whenever the parser tests for a token that would be accepted, but does not
-/// find it, it adds that token to the set. When the parser accepts a token, the
-/// set is cleared. If the parser finds a token which is unexpected, the
-/// contents of the set is printed in the resultant error message.
+/// all tokens which would have been accepted at the current point in the
+/// parse. Whenever the parser tests for a token that would be accepted, but
+/// does not find it, it adds that token to the set. When the parser accepts a
+/// token, the set is cleared. If the parser finds a token which is unexpected,
+/// the elements of the set are printed in the resultant error message.
 pub(crate) struct Parser<'run, 'src> {
   expected_tokens: BTreeSet<TokenKind>,
   file_depth: u32,
   file_path: &'run Path,
+  import_offsets: Vec<usize>,
   module_namepath: &'run Namepath<'src>,
   next_token: usize,
   recursion_depth: usize,
@@ -40,6 +41,7 @@ impl<'run, 'src> Parser<'run, 'src> {
   pub(crate) fn parse(
     file_depth: u32,
     file_path: &'run Path,
+    import_offsets: &[usize],
     module_namepath: &'run Namepath<'src>,
     submodule_depth: u32,
     tokens: &'run [Token<'src>],
@@ -49,6 +51,7 @@ impl<'run, 'src> Parser<'run, 'src> {
       expected_tokens: BTreeSet::new(),
       file_depth,
       file_path,
+      import_offsets: import_offsets.to_vec(),
       module_namepath,
       next_token: 0,
       recursion_depth: 0,
@@ -801,6 +804,7 @@ impl<'run, 'src> Parser<'run, 'src> {
       doc,
       file_depth: self.file_depth,
       file_path: self.file_path.into(),
+      import_offsets: self.import_offsets.clone(),
       name,
       namepath: self.module_namepath.join(name),
       parameters: positional.into_iter().chain(variadic).collect(),
@@ -913,6 +917,7 @@ impl<'run, 'src> Parser<'run, 'src> {
         Some(Setting::AllowDuplicateVariables(self.parse_set_bool()?))
       }
       Keyword::DotenvLoad => Some(Setting::DotenvLoad(self.parse_set_bool()?)),
+      Keyword::DotenvRequired => Some(Setting::DotenvRequired(self.parse_set_bool()?)),
       Keyword::Export => Some(Setting::Export(self.parse_set_bool()?)),
       Keyword::Fallback => Some(Setting::Fallback(self.parse_set_bool()?)),
       Keyword::IgnoreComments => Some(Setting::IgnoreComments(self.parse_set_bool()?)),
@@ -1040,6 +1045,7 @@ mod tests {
     let justfile = Parser::parse(
       0,
       &PathBuf::new(),
+      &[],
       &Namepath::default(),
       0,
       &tokens,
@@ -1086,6 +1092,7 @@ mod tests {
     match Parser::parse(
       0,
       &PathBuf::new(),
+      &[],
       &Namepath::default(),
       0,
       &tokens,
