@@ -31,14 +31,16 @@ pub(crate) enum Subcommand {
   Format,
   Groups,
   Init,
-  List,
+  List {
+    path: ModulePath,
+  },
   Man,
   Run {
     arguments: Vec<String>,
     overrides: BTreeMap<String, String>,
   },
   Show {
-    name: String,
+    path: ModulePath,
   },
   Summary,
   Variables,
@@ -88,8 +90,8 @@ impl Subcommand {
       Dump => Self::dump(config, ast, justfile)?,
       Format => Self::format(config, &search, src, ast)?,
       Groups => Self::groups(config, justfile),
-      List => Self::list(config, 0, justfile),
-      Show { ref name } => Self::show(config, name, justfile)?,
+      List { path } => Self::list(config, justfile, path)?,
+      Show { path } => Self::show(config, justfile, path)?,
       Summary => Self::summary(config, justfile),
       Variables => Self::variables(justfile),
       Changelog | Completions { .. } | Edit | Init | Man | Run { .. } => unreachable!(),
@@ -259,14 +261,15 @@ impl Subcommand {
     };
 
     for recipe in recipes {
-      if let Err(io_error) = child
-        .stdin
-        .as_mut()
-        .expect("Child was created with piped stdio")
-        .write_all(format!("{}\n", recipe.namepath).as_bytes())
-      {
-        return Err(Error::ChooserWrite { io_error, chooser });
-      }
+      writeln!(
+        child.stdin.as_mut().unwrap(),
+        "{}",
+        recipe.namepath.spaced()
+      )
+      .map_err(|io_error| Error::ChooserWrite {
+        io_error,
+        chooser: chooser.clone(),
+      })?;
     }
 
     let output = match child.wait_with_output() {
@@ -477,16 +480,25 @@ impl Subcommand {
     Ok(())
   }
 
-  fn list(config: &Config, level: usize, justfile: &Justfile) {
+  fn list(config: &Config, mut module: &Justfile, path: &ModulePath) -> Result<(), Error<'static>> {
+    for name in &path.path {
+      module = module
+        .modules
+        .get(name)
+        .ok_or_else(|| Error::UnknownSubmodule { path: path.clone() })?;
+    }
+
+    Self::list_module(config, module, 0);
+
+    Ok(())
+  }
+
+  fn list_module(config: &Config, module: &Justfile, depth: usize) {
     let aliases = if config.no_aliases {
       BTreeMap::new()
     } else {
       let mut aliases = BTreeMap::<&str, Vec<&str>>::new();
-      for alias in justfile
-        .aliases
-        .values()
-        .filter(|alias| !alias.is_private())
-      {
+      for alias in module.aliases.values().filter(|alias| !alias.is_private()) {
         aliases
           .entry(alias.target.name.lexeme())
           .or_default()
@@ -498,7 +510,7 @@ impl Subcommand {
     let signature_widths = {
       let mut signature_widths: BTreeMap<&str, usize> = BTreeMap::new();
 
-      for (name, recipe) in &justfile.recipes {
+      for (name, recipe) in &module.recipes {
         if !recipe.is_public() {
           continue;
         }
@@ -526,13 +538,15 @@ impl Subcommand {
       .max()
       .unwrap_or(0);
 
-    if level == 0 {
+    let list_prefix = config.list_prefix.repeat(depth + 1);
+
+    if depth == 0 {
       print!("{}", config.list_heading);
     }
 
     let groups = {
       let mut groups = BTreeMap::<Option<String>, Vec<&Recipe>>::new();
-      for recipe in justfile.public_recipes(config) {
+      for recipe in module.public_recipes(config) {
         let recipe_groups = recipe.groups();
         if recipe_groups.is_empty() {
           groups.entry(None).or_default().push(recipe);
@@ -553,7 +567,7 @@ impl Subcommand {
       let no_groups = groups.contains_key(&None) && groups.len() == 1;
 
       if !no_groups {
-        print!("{}", config.list_prefix.repeat(level + 1));
+        print!("{list_prefix}");
         if let Some(group_name) = group {
           println!("[{group_name}]");
         } else {
@@ -566,55 +580,88 @@ impl Subcommand {
           .chain(aliases.get(recipe.name()).unwrap_or(&Vec::new()))
           .enumerate()
         {
-          print!(
-            "{}{}",
-            config.list_prefix.repeat(level + 1),
-            RecipeSignature { name, recipe }.color_display(config.color.stdout())
-          );
-
           let doc = if i == 0 {
             recipe.doc().map(Cow::Borrowed)
           } else {
             Some(Cow::Owned(format!("alias for `{}`", recipe.name)))
           };
 
+          if let Some(doc) = &doc {
+            if doc.lines().count() > 1 {
+              for line in doc.lines() {
+                println!(
+                  "{list_prefix}{} {}",
+                  config.color.stdout().doc().paint("#"),
+                  config.color.stdout().doc().paint(line),
+                );
+              }
+            }
+          }
+
+          print!(
+            "{list_prefix}{}",
+            RecipeSignature { name, recipe }.color_display(config.color.stdout())
+          );
+
           if let Some(doc) = doc {
-            print!(
-              "{:padding$}{} {}",
-              "",
-              config.color.stdout().doc().paint("#"),
-              config.color.stdout().doc().paint(&doc),
-              padding = max_signature_width.saturating_sub(signature_widths[name]) + 1,
-            );
+            if doc.lines().count() <= 1 {
+              print!(
+                "{:padding$}{} {}",
+                "",
+                config.color.stdout().doc().paint("#"),
+                config.color.stdout().doc().paint(&doc),
+                padding = max_signature_width.saturating_sub(signature_widths[name]) + 1,
+              );
+            }
           }
           println!();
         }
       }
     }
 
-    for (i, module) in justfile.modules(config).into_iter().enumerate() {
-      if i + groups.len() > 0 {
-        println!();
-      }
+    if config.list_submodules {
+      for (i, submodule) in module.modules(config).into_iter().enumerate() {
+        if i + groups.len() > 0 {
+          println!();
+        }
 
-      println!("{}{}:", config.list_prefix.repeat(level + 1), module.name());
-      Self::list(config, level + 1, module);
+        println!("{list_prefix}{}:", submodule.name());
+
+        Self::list_module(config, submodule, depth + 1);
+      }
+    } else {
+      for submodule in module.modules(config) {
+        println!("{list_prefix}{} ...", submodule.name(),);
+      }
     }
   }
 
-  fn show<'src>(config: &Config, name: &str, justfile: &Justfile<'src>) -> Result<(), Error<'src>> {
-    if let Some(alias) = justfile.get_alias(name) {
-      let recipe = justfile.get_recipe(alias.target.name.lexeme()).unwrap();
+  fn show<'src>(
+    config: &Config,
+    mut module: &Justfile<'src>,
+    path: &ModulePath,
+  ) -> Result<(), Error<'src>> {
+    for name in &path.path[0..path.path.len() - 1] {
+      module = module
+        .modules
+        .get(name)
+        .ok_or_else(|| Error::UnknownSubmodule { path: path.clone() })?;
+    }
+
+    let name = path.path.last().unwrap();
+
+    if let Some(alias) = module.get_alias(name) {
+      let recipe = module.get_recipe(alias.target.name.lexeme()).unwrap();
       println!("{alias}");
       println!("{}", recipe.color_display(config.color.stdout()));
       Ok(())
-    } else if let Some(recipe) = justfile.get_recipe(name) {
+    } else if let Some(recipe) = module.get_recipe(name) {
       println!("{}", recipe.color_display(config.color.stdout()));
       Ok(())
     } else {
       Err(Error::UnknownRecipes {
         recipes: vec![name.to_owned()],
-        suggestion: justfile.suggest_recipe(name),
+        suggestion: module.suggest_recipe(name),
       })
     }
   }
