@@ -156,11 +156,11 @@ fn doc_attribute_suppress() {
   Test::new()
     .justfile(
       "
-    # Non-document comment
-    [doc]
-    foo:
-      echo foo
-  ",
+        # Non-document comment
+        [doc]
+        foo:
+          echo foo
+      ",
     )
     .args(["--list"])
     .stdout(
@@ -171,3 +171,25 @@ fn doc_attribute_suppress() {
     )
     .run();
 }
+
+#[test]
+fn doc_multiline() {
+  Test::new()
+    .justfile(
+      "
+        [doc('multiline
+        comment')]
+        foo:
+      ",
+    )
+    .args(["--list"])
+    .stdout(
+      "
+    Available recipes:
+        # multiline
+        # comment
+        foo
+        ",
+    )
+    .run();
+}
