@@ -12,40 +12,54 @@ fn dotenv() {
     .run();
 }
 
-test! {
-  name:     set_false,
-  justfile: r#"
-    set dotenv-load := false
+#[test]
+fn set_false() {
+  Test::new()
+    .justfile(
+      r#"
+      set dotenv-load := false
 
-    foo:
-      if [ -n "${DOTENV_KEY+1}" ]; then echo defined; else echo undefined; fi
-  "#,
-  stdout:   "undefined\n",
-  stderr:   "if [ -n \"${DOTENV_KEY+1}\" ]; then echo defined; else echo undefined; fi\n",
+      @foo:
+        if [ -n "${DOTENV_KEY+1}" ]; then echo defined; else echo undefined; fi
+    "#,
+    )
+    .write(".env", "DOTENV_KEY=dotenv-value")
+    .stdout("undefined\n")
+    .run();
 }
 
-test! {
-  name:     set_implicit,
-  justfile: r#"
-    set dotenv-load
+#[test]
+fn set_implicit() {
+  Test::new()
+    .justfile(
+      "
+        set dotenv-load
 
-    foo:
-      echo $DOTENV_KEY
-  "#,
-  stdout:   "dotenv-value\n",
-  stderr:   "echo $DOTENV_KEY\n",
+        foo:
+          echo $DOTENV_KEY
+      ",
+    )
+    .write(".env", "DOTENV_KEY=dotenv-value")
+    .stdout("dotenv-value\n")
+    .stderr("echo $DOTENV_KEY\n")
+    .run();
 }
 
-test! {
-  name:     set_true,
-  justfile: r#"
-    set dotenv-load := true
+#[test]
+fn set_true() {
+  Test::new()
+    .justfile(
+      "
+        set dotenv-load := true
 
-    foo:
-      echo $DOTENV_KEY
-  "#,
-  stdout:   "dotenv-value\n",
-  stderr:   "echo $DOTENV_KEY\n",
+        foo:
+          echo $DOTENV_KEY
+      ",
+    )
+    .write(".env", "DOTENV_KEY=dotenv-value")
+    .stdout("dotenv-value\n")
+    .stderr("echo $DOTENV_KEY\n")
+    .run();
 }
 
 #[test]
@@ -53,32 +67,28 @@ fn no_warning() {
   Test::new()
     .justfile(
       "
-      foo:
-        echo ${DOTENV_KEY:-unset}
-    ",
+        foo:
+          echo ${DOTENV_KEY:-unset}
+      ",
     )
+    .write(".env", "DOTENV_KEY=dotenv-value")
     .stdout("unset\n")
     .stderr("echo ${DOTENV_KEY:-unset}\n")
     .run();
 }
 
 #[test]
-fn path_not_found() {
+fn dotenv_required() {
   Test::new()
     .justfile(
       "
-      foo:
-        echo $JUST_TEST_VARIABLE
-    ",
+        set dotenv-required
+
+        foo:
+      ",
     )
-    .args(["--dotenv-path", ".env.prod"])
-    .stderr(if cfg!(windows) {
-      "error: Failed to load environment file: The system cannot find the file specified. (os \
-       error 2)\n"
-    } else {
-      "error: Failed to load environment file: No such file or directory (os error 2)\n"
-    })
-    .status(EXIT_FAILURE)
+    .stderr("error: Dotenv file not found\n")
+    .status(1)
     .run();
 }
 
@@ -87,9 +97,9 @@ fn path_resolves() {
   Test::new()
     .justfile(
       "
-      foo:
-        @echo $JUST_TEST_VARIABLE
-    ",
+        foo:
+          @echo $JUST_TEST_VARIABLE
+      ",
     )
     .tree(tree! {
       subdir: {
@@ -107,9 +117,9 @@ fn filename_resolves() {
   Test::new()
     .justfile(
       "
-      foo:
-        @echo $JUST_TEST_VARIABLE
-    ",
+        foo:
+          @echo $JUST_TEST_VARIABLE
+      ",
     )
     .tree(tree! {
       ".env.special": "JUST_TEST_VARIABLE=bar"
@@ -145,11 +155,11 @@ fn path_flag_overwrites_no_load() {
   Test::new()
     .justfile(
       "
-      set dotenv-load := false
+        set dotenv-load := false
 
-      foo:
-        @echo $JUST_TEST_VARIABLE
-    ",
+        foo:
+          @echo $JUST_TEST_VARIABLE
+      ",
     )
     .tree(tree! {
       subdir: {
@@ -227,12 +237,12 @@ fn program_argument_has_priority_for_dotenv_filename() {
 fn program_argument_has_priority_for_dotenv_path() {
   Test::new()
     .justfile(
-      r#"
-        set dotenv-path := "subdir/.env"
+      "
+        set dotenv-path := 'subdir/.env'
 
         foo:
           @echo $JUST_TEST_VARIABLE
-      "#,
+      ",
     )
     .tree(tree! {
       subdir: {
@@ -257,8 +267,111 @@ fn dotenv_path_is_relative_to_working_directory() {
           @echo $DOTENV_KEY
       ",
     )
+    .write(".env", "DOTENV_KEY=dotenv-value")
     .tree(tree! { subdir: { } })
     .current_dir("subdir")
     .stdout("dotenv-value\n")
     .run();
 }
+
+#[test]
+fn dotenv_variable_in_recipe() {
+  Test::new()
+    .justfile(
+      "
+        set dotenv-load
+
+        echo:
+          echo $DOTENV_KEY
+      ",
+    )
+    .write(".env", "DOTENV_KEY=dotenv-value")
+    .stdout("dotenv-value\n")
+    .stderr("echo $DOTENV_KEY\n")
+    .run();
+}
+
+#[test]
+fn dotenv_variable_in_backtick() {
+  Test::new()
+    .justfile(
+      "
+        set dotenv-load
+        X:=`echo $DOTENV_KEY`
+        echo:
+          echo {{X}}
+      ",
+    )
+    .write(".env", "DOTENV_KEY=dotenv-value")
+    .stdout("dotenv-value\n")
+    .stderr("echo dotenv-value\n")
+    .run();
+}
+
+#[test]
+fn dotenv_variable_in_function_in_recipe() {
+  Test::new()
+    .justfile(
+      "
+        set dotenv-load
+        echo:
+          echo {{env_var_or_default('DOTENV_KEY', 'foo')}}
+          echo {{env_var('DOTENV_KEY')}}
+      ",
+    )
+    .write(".env", "DOTENV_KEY=dotenv-value")
+    .stdout("dotenv-value\ndotenv-value\n")
+    .stderr("echo dotenv-value\necho dotenv-value\n")
+    .run();
+}
+
+#[test]
+fn dotenv_variable_in_function_in_backtick() {
+  Test::new()
+    .justfile(
+      "
+  set dotenv-load
+  X:=env_var_or_default('DOTENV_KEY', 'foo')
+  Y:=env_var('DOTENV_KEY')
+  echo:
+    echo {{X}}
+    echo {{Y}}
+",
+    )
+    .write(".env", "DOTENV_KEY=dotenv-value")
+    .stdout("dotenv-value\ndotenv-value\n")
+    .stderr("echo dotenv-value\necho dotenv-value\n")
+    .run();
+}
+
+#[test]
+fn no_dotenv() {
+  Test::new()
+    .justfile(
+      "
+        X:=env_var_or_default('DOTENV_KEY', 'DEFAULT')
+        echo:
+          echo {{X}}
+      ",
+    )
+    .write(".env", "DOTENV_KEY=dotenv-value")
+    .arg("--no-dotenv")
+    .stdout("DEFAULT\n")
+    .stderr("echo DEFAULT\n")
+    .run();
+}
+#[test]
+fn dotenv_env_var_override() {
+  Test::new()
+    .justfile(
+      "
+        echo:
+          echo $DOTENV_KEY
+      ",
+    )
+    .write(".env", "DOTENV_KEY=dotenv-value")
+    .env("DOTENV_KEY", "not-the-dotenv-value")
+    .stdout("not-the-dotenv-value\n")
+    .stderr("echo $DOTENV_KEY\n")
+    .run();
+}
