@@ -46,8 +46,9 @@ fn alias() {
         "allow_duplicate_recipes": false,
         "allow_duplicate_variables": false,
         "dotenv_filename": null,
-        "dotenv_load": null,
+        "dotenv_load": false,
         "dotenv_path": null,
+        "dotenv_required": false,
         "export": false,
         "fallback": false,
         "positional_arguments": false,
@@ -84,8 +85,9 @@ fn assignment() {
         "allow_duplicate_recipes": false,
         "allow_duplicate_variables": false,
         "dotenv_filename": null,
-        "dotenv_load": null,
+        "dotenv_load": false,
         "dotenv_path": null,
+        "dotenv_required": false,
         "export": false,
         "fallback": false,
         "ignore_comments": false,
@@ -136,8 +138,9 @@ fn body() {
         "allow_duplicate_recipes": false,
         "allow_duplicate_variables": false,
         "dotenv_filename": null,
-        "dotenv_load": null,
+        "dotenv_load": false,
         "dotenv_path": null,
+        "dotenv_required": false,
         "export": false,
         "fallback": false,
         "ignore_comments": false,
@@ -200,8 +203,9 @@ fn dependencies() {
         "allow_duplicate_recipes": false,
         "allow_duplicate_variables": false,
         "dotenv_filename": null,
-        "dotenv_load": null,
+        "dotenv_load": false,
         "dotenv_path": null,
+        "dotenv_required": false,
         "export": false,
         "fallback": false,
         "ignore_comments": false,
@@ -302,8 +306,9 @@ fn dependency_argument() {
         "allow_duplicate_recipes": false,
         "allow_duplicate_variables": false,
         "dotenv_filename": null,
-        "dotenv_load": null,
+        "dotenv_load": false,
         "dotenv_path": null,
+        "dotenv_required": false,
         "export": false,
         "fallback": false,
         "ignore_comments": false,
@@ -366,8 +371,9 @@ fn duplicate_recipes() {
         "allow_duplicate_recipes": true,
         "allow_duplicate_variables": false,
         "dotenv_filename": null,
-        "dotenv_load": null,
+        "dotenv_load": false,
         "dotenv_path": null,
+        "dotenv_required": false,
         "export": false,
         "fallback": false,
         "ignore_comments": false,
@@ -408,8 +414,9 @@ fn duplicate_variables() {
         "allow_duplicate_recipes": false,
         "allow_duplicate_variables": true,
         "dotenv_filename": null,
-        "dotenv_load": null,
+        "dotenv_load": false,
         "dotenv_path": null,
+        "dotenv_required": false,
         "export": false,
         "fallback": false,
         "ignore_comments": false,
@@ -453,8 +460,9 @@ fn doc_comment() {
         "allow_duplicate_recipes": false,
         "allow_duplicate_variables": false,
         "dotenv_filename": null,
-        "dotenv_load": null,
+        "dotenv_load": false,
         "dotenv_path": null,
+        "dotenv_required": false,
         "export": false,
         "fallback": false,
         "ignore_comments": false,
@@ -484,8 +492,9 @@ fn empty_justfile() {
         "allow_duplicate_recipes": false,
         "allow_duplicate_variables": false,
         "dotenv_filename": null,
-        "dotenv_load": null,
+        "dotenv_load": false,
         "dotenv_path": null,
+        "dotenv_required": false,
         "export": false,
         "fallback": false,
         "ignore_comments": false,
@@ -636,8 +645,9 @@ fn parameters() {
         "allow_duplicate_recipes": false,
         "allow_duplicate_variables": false,
         "dotenv_filename": null,
-        "dotenv_load": null,
+        "dotenv_load": false,
         "dotenv_path": null,
+        "dotenv_required": false,
         "export": false,
         "fallback": false,
         "ignore_comments": false,
@@ -721,8 +731,9 @@ fn priors() {
         "allow_duplicate_recipes": false,
         "allow_duplicate_variables": false,
         "dotenv_filename": null,
-        "dotenv_load": null,
+        "dotenv_load": false,
         "dotenv_path": null,
+        "dotenv_required": false,
         "export": false,
         "fallback": false,
         "ignore_comments": false,
@@ -766,8 +777,9 @@ fn private() {
         "allow_duplicate_recipes": false,
         "allow_duplicate_variables": false,
         "dotenv_filename": null,
-        "dotenv_load": null,
+        "dotenv_load": false,
         "dotenv_path": null,
+        "dotenv_required": false,
         "export": false,
         "fallback": false,
         "ignore_comments": false,
@@ -811,8 +823,9 @@ fn quiet() {
         "allow_duplicate_recipes": false,
         "allow_duplicate_variables": false,
         "dotenv_filename": null,
-        "dotenv_load": null,
+        "dotenv_load": false,
         "dotenv_path": null,
+        "dotenv_required": false,
         "export": false,
         "fallback": false,
         "ignore_comments": false,
@@ -870,6 +883,7 @@ fn settings() {
         "dotenv_filename": "filename",
         "dotenv_load": true,
         "dotenv_path": "path",
+        "dotenv_required": false,
         "export": true,
         "fallback": true,
         "ignore_comments": true,
@@ -919,8 +933,9 @@ fn shebang() {
         "allow_duplicate_recipes": false,
         "allow_duplicate_variables": false,
         "dotenv_filename": null,
-        "dotenv_load": null,
+        "dotenv_load": false,
         "dotenv_path": null,
+        "dotenv_required": false,
         "export": false,
         "fallback": false,
         "ignore_comments": false,
@@ -964,8 +979,9 @@ fn simple() {
         "allow_duplicate_recipes": false,
         "allow_duplicate_variables": false,
         "dotenv_filename": null,
-        "dotenv_load": null,
+        "dotenv_load": false,
         "dotenv_path": null,
+        "dotenv_required": false,
         "export": false,
         "fallback": false,
         "ignore_comments": false,
@@ -1012,8 +1028,9 @@ fn attribute() {
         "allow_duplicate_recipes": false,
         "allow_duplicate_variables": false,
         "dotenv_filename": null,
-        "dotenv_load": null,
+        "dotenv_load": false,
         "dotenv_path": null,
+        "dotenv_required": false,
         "export": false,
         "fallback": false,
         "positional_arguments": false,
@@ -1073,8 +1090,9 @@ fn module() {
               "allow_duplicate_recipes": false,
               "allow_duplicate_variables": false,
               "dotenv_filename": null,
-              "dotenv_load": null,
+              "dotenv_load": false,
               "dotenv_path": null,
+              "dotenv_required": false,
               "export": false,
               "fallback": false,
               "positional_arguments": false,
@@ -1093,8 +1111,9 @@ fn module() {
           "allow_duplicate_recipes": false,
           "allow_duplicate_variables": false,
           "dotenv_filename": null,
-          "dotenv_load": null,
+          "dotenv_load": false,
           "dotenv_path": null,
+          "dotenv_required": false,
           "export": false,
           "fallback": false,
           "positional_arguments": false,
