@@ -884,7 +884,7 @@ _private-recipe:
   args:     ("--list"),
   stdout:   r#"
     Available recipes:
-        a Z="\t z"          # something else
+        a Z="\t z"           # something else
         hello a b='B	' c='C' # this does a thing
   "#,
 }
@@ -1589,84 +1589,6 @@ echo:
    stderr:   "echo 1\n",
 }
 
-test! {
-   name:     dotenv_variable_in_recipe,
-   justfile: "
-#
-set dotenv-load
-
-echo:
-  echo $DOTENV_KEY
- ",
-   stdout:   "dotenv-value\n",
-   stderr:   "echo $DOTENV_KEY\n",
-}
-
-test! {
-   name:     dotenv_variable_in_backtick,
-   justfile: "
-#
-set dotenv-load
-X:=`echo $DOTENV_KEY`
-echo:
-  echo {{X}}
- ",
-   stdout:   "dotenv-value\n",
-   stderr:   "echo dotenv-value\n",
-}
-test! {
-   name:     dotenv_variable_in_function_in_recipe,
-   justfile: "
-#
-set dotenv-load
-echo:
-  echo {{env_var_or_default('DOTENV_KEY', 'foo')}}
-  echo {{env_var('DOTENV_KEY')}}
- ",
-   stdout:   "dotenv-value\ndotenv-value\n",
-   stderr:   "echo dotenv-value\necho dotenv-value\n",
-}
-
-test! {
-   name:     dotenv_variable_in_function_in_backtick,
-   justfile: "
-#
-set dotenv-load
-X:=env_var_or_default('DOTENV_KEY', 'foo')
-Y:=env_var('DOTENV_KEY')
-echo:
-  echo {{X}}
-  echo {{Y}}
- ",
-   stdout:   "dotenv-value\ndotenv-value\n",
-   stderr:   "echo dotenv-value\necho dotenv-value\n",
-}
-
-test! {
-   name:     no_dotenv,
-   justfile: "
-#
-X:=env_var_or_default('DOTENV_KEY', 'DEFAULT')
-echo:
-  echo {{X}}
- ",
-   args:     ("--no-dotenv"),
-   stdout:   "DEFAULT\n",
-   stderr:   "echo DEFAULT\n",
-}
-
-test! {
-   name:     dotenv_env_var_override,
-   justfile: "
-#
-echo:
-  echo $DOTENV_KEY
- ",
-   env:      {"DOTENV_KEY": "not-the-dotenv-value",},
-   stdout:   "not-the-dotenv-value\n",
-   stderr:   "echo $DOTENV_KEY\n",
-}
-
 test! {
    name:     invalid_escape_sequence_message,
    justfile: r#"
