@@ -201,9 +201,8 @@ impl Test {
     } else {
       self.stdout.clone()
     };
-    let stderr = unindent(&self.stderr);
 
-    fs::write(self.tempdir.path().join(".env"), "DOTENV_KEY=dotenv-value").unwrap();
+    let stderr = unindent(&self.stderr);
 
     let mut command = Command::new(executable_path("just"));
 
@@ -258,7 +257,7 @@ impl Test {
       }
     }
 
-    if !compare("status", output.status.code().unwrap(), self.status)
+    if !compare("status", output.status.code(), Some(self.status))
       | (self.stdout_regex.is_none() && !compare("stdout", output_stdout, &stdout))
       | (self.stderr_regex.is_none() && !compare("stderr", output_stderr, &stderr))
     {
